# spatial_regression_notebooks
Jupyter notebooks to illustrate spatial regression functionality

## Recommended Installation
The safest installation is in a separate *environment* with the following installed packages. The version listed is the one used for the notebooks:

- numpy 2.1.1
- scipy 1.14.1
- scikit-learn 1.5.1
- pandas 2.2.2
- matplotlib 3.9.2
- seaborn 0.13.2
- pysal 24.07 (this will also install geopandas, otherwise, a separate installation of geopandas is required)
- jupyter 1.1.1

Make sure the version of spreg is 1.7. pysal 24.07 includes 1.6.1. To obtain the latest version, use pip install --upgrade spreg.
